<?php
/*---------------------------------------------------------------------------------*/
/* Portfolio Custom Post Type */
/*---------------------------------------------------------------------------------*/
add_action('init', 'portfolio_register');
 
function portfolio_register() {
 
	$labels = array(
		'name' => _x('My Portfolio', 'post type general name'),
		'singular_name' => _x('Portfolio Item', 'post type singular name'),
		'add_new' => _x('Add New', 'portfolio item'),
		'add_new_item' => __('Add New Portfolio Item'),
		'edit_item' => __('Edit Portfolio Item'),
		'new_item' => __('New Portfolio Item'),
		'view_item' => __('View Portfolio Item'),
		'search_items' => __('Search Portfolio'),
		'not_found' =>  __('Nothing found'),
		'not_found_in_trash' => __('Nothing found in Trash'),
		'parent_item_colon' => ''
	);
 
	$args = array(
		'labels' => $labels,
		'public' => true,
		'publicly_queryable' => true,
		'show_ui' => true,
		'query_var' => true,
		'menu_icon' => get_bloginfo('template_directory') . '/images/tt_logo.png',
		'rewrite' => true,
		'capability_type' => 'post',
		'hierarchical' => false,
		'menu_position' => null,
		'supports' => array('title','editor','excerpt','thumbnail')
	  ); 
 
	register_post_type( 'portfolio' , $args );
}
//register a custom taxonomy for portfolio
register_taxonomy("skills", array("portfolio"), array("hierarchical" => true, "label" => "Skills", "singular_label" => "Skill", "rewrite" => true));

add_action("admin_init", "admin_init");
 
function admin_init(){
  add_meta_box("credits_meta", __('Theme Team Custom Portfolio Options','themeteam'), "credits_meta", "portfolio", "normal", "low");
}
 
function credits_meta() {
  global $post;
  $custom = get_post_custom($post->ID);
  $work_involved = $custom["work_involved"][0];
  $website_url = $custom["website_url"][0];
  $themeteam_image_upload = $custom["themeteam_image_upload"][0];
  $themeteam_video_embed = $custom["themeteam_video_embed"][0];
  
  // Use nonce for verification
  wp_nonce_field( plugin_basename(__FILE__), 'themeteam_portfolio' );
  
  ?>
  <style type="text/css">
	.input_text { margin:0 0 10px 0; background:#f4f4f4; color:#444; width:80%; font-size:11px; padding: 5px;}
	.input_select { margin:0 0 10px 0; background:#f4f4f4; color:#444; width:60%; font-size:11px; padding: 5px;}
	.input_checkbox { margin:0 10px 0 0; }
	.spacer { display: block; height:5px}
	.metabox_desc { font-size:10px; color:#aaa; display:block}
	.metaboxes{ border-collapse:collapse; width:100%}
	.metaboxes tr:hover th,
	.metaboxes tr:hover td { background:#f8f8f8}
	.metaboxes th,
	.metaboxes td{ border-bottom:1px solid #ddd; padding:10px 10px;text-align: left; vertical-align:top}
	.metabox_th { width:20%}
	.input_textarea { width:80%; height:120px;margin:0 0 10px 0; background:#f0f0f0; color:#444;font-size:11px;padding: 5px;}
  </style>
  <table class="metaboxes">
  	<tr>
  		<th class="metabox_th"><label for="work_involved">Work Involved:</label></th>
  		<td><input class="input_text" type="text" name="work_involved" id="work_involved" value="<?php echo $work_involved; ?>"/>
  		<span class="metabox_desc">Enter the work involved</span></td>
  		<td></td>
  	</tr>
	<tr>
  		<th class="metabox_th"><label for="website_url">Website URL:</label></th>
  		<td><input class="input_text" type="text" name="website_url" id="website_url" value="<?php echo $website_url; ?>"/>
  		<span class="metabox_desc">Enter the url of the portfolio piece.</span></td>
  		<td></td>
  	</tr>
    <tr>
    	<th class="metabox_th"><label for="themeteam_video_embed"><?php echo _e('Video URL','themeteam');?></label></th>
    	<td>
		<input class="input_text" type="text" name="themeteam_video_embed" id="themeteam_video_embed" value="<?php echo $themeteam_video_embed; ?>"/>
    	<span class="metabox_desc"><?php echo _e('Place the url for your video.','themeteam');?></span></td>
    	<td></td>
    </tr>
  </table>
  <?php
}

add_action('save_post', 'save_details');

function save_details(){
  global $post;
  
  // verify this came from the our screen and with proper authorization,
  // because save_post can be triggered at other times

  if ( !wp_verify_nonce( $_POST['themeteam_portfolio'], plugin_basename(__FILE__) )) {
    return $post_id;
  }

  // verify if this is an auto save routine. If it is our form has not been submitted, so we dont want
  // to do anything
  if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) 
    return $post_id;
 
  update_post_meta($post->ID, "work_involved", $_POST["work_involved"]);
  update_post_meta($post->ID, "website_url", $_POST["website_url"]);
  update_post_meta($post->ID, "themeteam_video_embed" , $_POST["themeteam_video_embed"]);
}

add_action("manage_posts_custom_column",  "portfolio_custom_columns");
add_filter("manage_edit-portfolio_columns", "portfolio_edit_columns");
 
function portfolio_edit_columns($columns){
  $columns = array(
    "cb" => "<input type=\"checkbox\" />",
    "title" => "Portfolio Title",
    "description" => "Description",
    "work_involved" => "Work Involved",
    "skills" => "Skills",
  );
 
  return $columns;
}
function portfolio_custom_columns($column){
  global $post;
 
  switch ($column) {
    case "description":
      the_excerpt();
      break;
    case "year":
      $custom = get_post_custom();
      echo $custom["year_completed"][0];
      break;
    case "skills":
      echo get_the_term_list($post->ID, 'skills', '', ', ','');
      break;
  }
}
?>